@@ -1,6 +1,6 @@
 from collections import Counter
 
-from django.contrib.messages import api, constants
+from django.contrib.messages import constants
 from django.utils.translation import gettext as _
 
 
@@ -22,9 +22,6 @@ class Message:
             and self.message == other.message
         )
 
-    def add_to(self, request):
-        api.add_message(request, self.level, self.message)
-
 
 class Warning(Message):
     def __init__(self, *args, **kwargs):
